@@ -563,7 +563,7 @@ would replace the <Alt-n> with the client's name in each window.}
     output $self->loc(
         q{All comments (marked by a #) and blank lines are ignored.  Tags may be nested, but be aware of using recursive tags as they are not checked for.}
     );
-    output $self->loc(q{Servers can be defined using bash shell expansion:});
+    output $self->loc(q{Servers can be defined using expansion macros:});
     output 'C<< webservers websvr{a,b,c} >>';
     output $self->loc(q{would be expanded to});
     output 'C<< webservers websvra websvrb websvrc >>';
@@ -571,10 +571,7 @@ would replace the <Alt-n> with the client's name in each window.}
     output 'C<< webservers websvr{6..9} >>';
     output $self->loc(q{would be expanded to});
     output 'C<< webservers websvr6 websvr7 websvr8 websvr9 >>';
-    output $self->loc(
-        q{B<NOTE:> this requires [_1] to be installed on your system (see [_2] configuration option },
-        '/bin/bash', 'C<shell_expansion>'
-    );
+
     output $self->loc(
         q{Extra cluster files may also be specified either as an option on the command line (see [_1]) or in the user's [_2] file (see [_3] configuration option).},
         'C<cluster-file>',
@@ -772,13 +769,6 @@ B<NOTE:> Any "generic" change to the method (e.g., specifying the ssh port to us
         q{Number of pixels from the screen's side to reserve when calculating screen geometry for tiling.  Setting this to something like 50 will help keep cssh from positioning windows over your window manager's menu bar if it draws one at that side of the screen.}
     );
 
-    output
-        q{=item shell_expansion = /bin/bash -c 'shopt -s extglob\n echo %items%'"};
-    output $self->loc(
-        q{Command used to expand a given string (provided by the macro [_1]) - used for expanding host names when a [_2] is in the name.  See [_3]},
-        'C<%items%>', 'C<{>', 'L<bash/EXPANSION>'
-    );
-
     output '=item terminal = /path/to/xterm';
     output $self->loc(q{Path to the X-Windows terminal used for the client.});
 
