@@ -1,30 +1,13 @@
+package App::ClusterSSH::Host;
+
 use strict;
 use warnings;
 
-package App::ClusterSSH::Host;
-$App::ClusterSSH::Host::VERSION = '4.18_06'; # TRIAL
-$App::ClusterSSH::Host::VERSION = '4.1806';
-# ABSTRACT: ClusterSSH::Host - Object representing a host.
-
-=head1 SYNOPSIS
-
-    use ClusterSSH::Host;
-
-    my $host = ClusterSSH::Host->new({
-        hostname => 'hostname',
-    });
-    my $host = ClusterSSH::Host->parse_host_string('username@hostname:1234');
-
-=head1 DESCRIPTION
-
-Object representing a host.  Include details to contact the host such as
-hostname/ipaddress, username and port.
-
-=cut
+use version;
+our $VERSION = version->new('0.03');
 
 use Carp;
 use Net::hostent;
-use File::Basename qw(dirname);
 
 use base qw/ App::ClusterSSH::Base /;
 
@@ -54,65 +37,28 @@ sub new {
 
     # load in ssh hostname for later use
     if ( !%ssh_hostname_for || !$ssh_configs_read{ $self->{ssh_config} } ) {
-        $self->read_ssh_file( $self->{ssh_config} );
-
-        $self->debug( 5, 'Have the following ssh hostnames' );
-        $self->debug( 5, '  "', $_, '"' )
-            foreach ( sort keys %ssh_hostname_for );
-    }
-
-    return $self;
-}
-
-sub read_ssh_file($$) {
-    my ($self)    = shift;
-    my ($pattern) = @_;
-
-    my @files = glob $pattern;
-
-    if ( !@files ) {
-        $self->debug( 3, 'SSH include pattern matched no files: ', $pattern );
-        return;
-    }
-
-    foreach my $filename (@files) {
-        next if ( !defined $filename || $filename eq q{} );
-        next if ( $ssh_configs_read{$filename} );
-
-        $self->debug( 3, 'Reading SSH file: ', $filename );
-
-        $ssh_configs_read{$filename} = 1;
-
-        if ( open( my $ssh_config_fh, '<', $filename ) ) {
-            my $basedir = dirname($filename);
-
+        $ssh_configs_read{ $self->{ssh_config} } = 1;
+        if ( open( my $ssh_config_fh, '<', $self->{ssh_config} ) ) {
             while ( my $line = <$ssh_config_fh> ) {
                 chomp $line;
-
-                if ( $line =~ /^\s*include\s+(.+)/i ) {
-                    my $include = $1;
-                    $include =~ s/^\s+//;
-                    $include =~ s/\s+$//;
-
-                    if ( $include !~ m{^[/~]} ) {
-                        $include = $basedir . '/' . $include;
-                    }
-
-                    $self->read_ssh_file($include);
-                    next;
-                }
-
                 next unless ( $line =~ m/^\s*host\s+(.*)/i );
 
                 # account for multiple declarations of hosts
                 $ssh_hostname_for{$_} = 1 foreach ( split( /\s+/, $1 ) );
             }
             close($ssh_config_fh);
+
+            $self->debug( 5, 'Have the following ssh hostnames' );
+            $self->debug( 5, '  "', $_, '"' )
+                foreach ( sort keys %ssh_hostname_for );
         }
         else {
-            $self->debug( 3, 'Unable to read ', $filename, ': ', $!, $/ );
+            $self->debug( 3, 'Unable to read ',
+                $self->{ssh_config}, ': ', $!, $/ );
         }
     }
+
+    return $self;
 }
 
 sub get_hostname {
@@ -349,11 +295,9 @@ sub check_ssh_hostname {
         $self->get_hostname );
 
     if ( $ssh_hostname_for{ $self->get_hostname } ) {
-        $self->debug( 5, 'Found' );
         return 1;
     }
     else {
-        $self->debug( 5, 'Not found' );
         return 0;
     }
 }
@@ -368,6 +312,26 @@ use overload (
 
 1;
 
+=pod
+
+=head1 NAME
+
+ClusterSSH::Host - Object representing a host.
+
+=head1 SYNOPSIS
+
+    use ClusterSSH::Host;
+
+    my $host = ClusterSSH::Host->new({
+        hostname => 'hostname',
+    });
+    my $host = ClusterSSH::Host->parse_host_string('username@hostname:1234');
+
+=head1 DESCRIPTION
+
+Object representing a host.  Include details to contact the host such as
+hostname/ipaddress, username and port.
+
 =head1 METHODS
 
 =over 4
@@ -406,7 +370,7 @@ Set specific details about the host after its been created.
 =item get_realname
 
 If the server name provided is not an IP address (either IPv4 or IPv6) 
-attempt to resolve it and return the discovered names.
+attempt to resolve it and retun the discovered names.
 
 =item get_givenname
 
@@ -422,11 +386,6 @@ Given a host string, returns a host object.  Parses hosts such as
 Check the objects hostname to see whether or not it may be configured within 
 the users F< $HOME/.ssh/config > configuration file
 
-=item read_ssh_file
-
-Method to ease reading in ssh configuration files.  Used for grabbing
-hostnames for validation when used in clusters
-
 =over 4
 
 =item host
@@ -451,3 +410,21 @@ the IPv6 address or a port definition?) and assumes it is part of address.
 Use brackets to avoid seeing warning.
 
 =back
+
+=head1 AUTHOR
+
+Duncan Ferguson, C<< <duncan_j_ferguson at yahoo.co.uk> >>
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 1999-2015 Duncan Ferguson.
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
+
+See http://dev.perl.org/licenses/ for more information.
+
+=cut
+
+1;
